@@ -478,7 +478,7 @@ def create_new_position_flag(df,days):
         colname = 'new_position_'+str(days)
         df[colname] = 0
         df.loc[df['DaysSincePositionStart']< days,colname] = 1
-        logging.info(f'{df.colname.value_counts()}')
+        logging.info(f'{df[colname].value_counts()}')
     else:
         logging.info(' dayssincepositionstart Column not found, no changes were made.')
     return df
